@@ -13,6 +13,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/apimachinery/pkg/util/sets"
+	"k8s.io/klog"
 
 	configv1 "github.com/openshift/api/config/v1"
 	operatorv1 "github.com/openshift/api/operator/v1"
@@ -22,6 +23,7 @@ func defaultDeployment(
 	operatorConfig *operatorv1.Authentication,
 	syncData *configSyncData,
 	routerSecret *corev1.Secret,
+	proxyConfig *configv1.Proxy,
 	operatorDeployment *appsv1.Deployment,
 	resourceVersions ...string,
 ) *appsv1.Deployment {
@@ -35,41 +37,49 @@ func defaultDeployment(
 
 	for _, data := range []volume{
 		{
-			name:      sessionNameAndKey,
+			name:      "v4-0-config-system-session",
 			configmap: false,
-			path:      sessionMount,
-			keys:      []string{sessionNameAndKey},
+			path:      "/var/config/system/secrets/v4-0-config-system-session",
+			keys:      []string{"v4-0-config-system-session"},
 		},
 		{
-			name:      cliConfigNameAndKey,
+			name:      "v4-0-config-system-cliconfig",
 			configmap: true,
-			path:      cliConfigMount,
-			keys:      []string{cliConfigNameAndKey},
+			path:      "/var/config/system/configmaps/v4-0-config-system-cliconfig",
+			keys:      []string{"v4-0-config-system-cliconfig"},
 		},
 		{
-			name:      servingCertName,
+			name:      "v4-0-config-system-serving-cert",
 			configmap: false,
-			path:      servingCertMount,
+			path:      "/var/config/system/secrets/v4-0-config-system-serving-cert",
 			keys:      []string{corev1.TLSCertKey, corev1.TLSPrivateKeyKey},
 		},
 		{
-			name:      serviceCAName,
+			name:      "v4-0-config-system-service-ca",
 			configmap: true,
-			path:      serviceCAMount,
-			keys:      []string{serviceCAKey},
+			path:      "/var/config/system/configmaps/v4-0-config-system-service-ca",
+			keys:      []string{"service-ca.crt"},
 		},
 		{
-			name:      routerCertsLocalName,
+			name:      "v4-0-config-system-router-certs",
 			configmap: false,
-			path:      routerCertsLocalMount,
+			path:      "/var/config/system/secrets/v4-0-config-system-router-certs",
 			keys:      sets.StringKeySet(routerSecret.Data).List(),
 		},
 		{
-			name:      ocpBrandingSecretName,
+			name:      "v4-0-config-system-ocp-branding-template",
 			configmap: false,
-			path:      ocpBrandingSecretMount,
+			path:      "/var/config/system/secrets/v4-0-config-system-ocp-branding-template",
 			keys:      []string{configv1.LoginTemplateKey, configv1.ProviderSelectionTemplateKey, configv1.ErrorsTemplateKey},
 		},
+		{
+			name:      "v4-0-config-system-trusted-ca-bundle",
+			configmap: true,
+			path:      "/var/config/system/configmaps/v4-0-config-system-trusted-ca-bundle",
+			// make this config map volume optional as it may not always exist
+			// this will prevent the node from blocking the container create process when the resource is missing
+			optional: true,
+		},
 	} {
 		v, m := data.split()
 		volumes = append(volumes, v)
@@ -85,6 +95,7 @@ func defaultDeployment(
 	// need to sort first in order to get a stable array
 	sort.Strings(resourceVersions)
 	rvs := strings.Join(resourceVersions, ",")
+	klog.V(4).Infof("tracked resource versions: %s", rvs)
 	rvsHash := sha512.Sum512([]byte(rvs))
 	rvsHashStr := base64.RawURLEncoding.EncodeToString(rvsHash[:])
 
@@ -101,26 +112,31 @@ func defaultDeployment(
 			Template: corev1.PodTemplateSpec{
 				ObjectMeta: meta,
 				Spec: corev1.PodSpec{
-					ServiceAccountName: targetName,
+					ServiceAccountName: "oauth-openshift",
 					Containers: []corev1.Container{
 						{
 							Image:           oauthserverImage,
 							ImagePullPolicy: getImagePullPolicy(operatorDeployment),
-							Name:            targetName,
-							Command: []string{
-								"hypershift",
-								"openshift-osinserver",
-								fmt.Sprintf("--config=%s", cliConfigPath),
-								fmt.Sprintf("--v=%d", getLogLevel(operatorConfig.Spec.LogLevel)),
-							},
+							Name:            "oauth-openshift",
+							Command:         []string{"/bin/bash", "-ec"},
+							Args: []string{fmt.Sprintf(`
+if [ -s %s ]; then
+    echo "Copying system trust bundle"
+    cp -f %s /etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem
+fi
+exec oauth-server osinserver --config=%s --v=%d
+`, `/var/config/system/configmaps/v4-0-config-system-trusted-ca-bundle/ca-bundle.crt`,
+								`/var/config/system/configmaps/v4-0-config-system-trusted-ca-bundle/ca-bundle.crt`,
+								`/var/config/system/configmaps/v4-0-config-system-cliconfig/v4-0-config-system-cliconfig`, getLogLevel(operatorConfig.Spec.LogLevel))},
 							Ports: []corev1.ContainerPort{
 								{
 									Name:          "https",
 									Protocol:      corev1.ProtocolTCP,
-									ContainerPort: containerPort,
+									ContainerPort: 6443,
 								},
 							},
 							VolumeMounts:             mounts,
+							Env:                      proxyConfigToEnvVars(proxyConfig),
 							ReadinessProbe:           defaultProbe(),
 							LivenessProbe:            livenessProbe(),
 							TerminationMessagePolicy: corev1.TerminationMessageFallbackToLogsOnError,
@@ -183,7 +199,7 @@ func defaultProbe() *corev1.Probe {
 		Handler: corev1.Handler{
 			HTTPGet: &corev1.HTTPGetAction{
 				Path:   "/healthz",
-				Port:   intstr.FromInt(containerPort),
+				Port:   intstr.FromInt(6443),
 				Scheme: corev1.URISchemeHTTPS,
 			},
 		},
@@ -236,11 +252,31 @@ func getImagePullPolicy(operatorDeployment *appsv1.Deployment) corev1.PullPolicy
 	return containers[0].ImagePullPolicy
 }
 
+func proxyConfigToEnvVars(proxy *configv1.Proxy) []corev1.EnvVar {
+	envVars := []corev1.EnvVar{}
+
+	envVars = appendEnvVar(envVars, "NO_PROXY", proxy.Status.NoProxy)
+	envVars = appendEnvVar(envVars, "HTTP_PROXY", proxy.Status.HTTPProxy)
+	envVars = appendEnvVar(envVars, "HTTPS_PROXY", proxy.Status.HTTPSProxy)
+
+	return envVars
+}
+
+func appendEnvVar(envVars []corev1.EnvVar, envName, envVal string) []corev1.EnvVar {
+	if len(envVal) > 0 {
+		return append(envVars, corev1.EnvVar{Name: envName, Value: envVal})
+	}
+
+	return envVars
+}
+
 type volume struct {
-	name      string
-	configmap bool
-	path      string
-	keys      []string
+	name       string
+	configmap  bool
+	path       string
+	keys       []string
+	mappedKeys map[string]string
+	optional   bool
 }
 
 func (v *volume) split() (corev1.Volume, corev1.VolumeMount) {
@@ -249,6 +285,14 @@ func (v *volume) split() (corev1.Volume, corev1.VolumeMount) {
 	}
 
 	var items []corev1.KeyToPath
+	// maps' keys are random,  we need to sort the output to prevent redeployment hotloops
+	for _, key := range sets.StringKeySet(v.mappedKeys).List() {
+		items = append(items, corev1.KeyToPath{
+			Key:  key,
+			Path: v.mappedKeys[key],
+		})
+	}
+
 	for _, key := range v.keys {
 		items = append(items, corev1.KeyToPath{
 			Key:  key,
@@ -261,12 +305,14 @@ func (v *volume) split() (corev1.Volume, corev1.VolumeMount) {
 			LocalObjectReference: corev1.LocalObjectReference{
 				Name: v.name,
 			},
-			Items: items,
+			Items:    items,
+			Optional: &v.optional,
 		}
 	} else {
 		vol.Secret = &corev1.SecretVolumeSource{
 			SecretName: v.name,
 			Items:      items,
+			Optional:   &v.optional,
 		}
 	}
 
